@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 from django.contrib.auth.models import AnonymousUser
 from django.contrib.auth.models import User
+from django.conf import settings
+
 
 class AuthMiddleware(object):
 
@@ -11,5 +13,6 @@ class AuthMiddleware(object):
             if identity is not None:
                 repoze_who_user = identity['repoze.who.userid']
             if repoze_who_user is not None:
-                user = User.objects.get(email=repoze_who_user)
+                user = User.objects.get(**{settings.LOGIN_FIELD:
+                                           repoze_who_user})
                 request.user = user
